@@ -500,8 +500,16 @@ collection_account_wizard_worker_finished_cb (EConfigLookup *config_lookup,
 
 		link = g_markup_printf_escaped ("<a href=\"evo:enter-password\">%s</a>", _("Enter password"));
 
-		/* Translators: The %s is replaced with a clickable text "Enter password", thus it'll be "Requires password to continue. Enter password." at the end. */
-		markup = g_strdup_printf (_("Requires password to continue. %s."), link);
+		if (error->message && *error->message) {
+			gchar *escaped;
+
+			escaped = g_markup_escape_text (error->message, -1);
+			markup = g_strconcat (escaped, " ", link, NULL);
+			g_free (escaped);
+		} else {
+			/* Translators: The %s is replaced with a clickable text "Enter password", thus it'll be "Requires password to continue. Enter password." at the end. */
+			markup = g_strdup_printf (_("Requires password to continue. %s."), link);
+		}
 
 		gtk_label_set_markup (GTK_LABEL (wd->running_label), markup);
 
@@ -510,17 +518,20 @@ collection_account_wizard_worker_finished_cb (EConfigLookup *config_lookup,
 	} else if (g_error_matches (error, E_CONFIG_LOOKUP_WORKER_ERROR, E_CONFIG_LOOKUP_WORKER_ERROR_CERTIFICATE) &&
 		   restart_params && e_named_parameters_exists (restart_params, E_CONFIG_LOOKUP_PARAM_CERTIFICATE_PEM) &&
 		   e_named_parameters_exists (restart_params, E_CONFIG_LOOKUP_PARAM_CERTIFICATE_HOST)) {
-		gchar *markup, *link;
+		gchar *markup, *link, *escaped = NULL;
 
 		wd->certificate_error = g_strdup (error->message);
 
 		link = g_markup_printf_escaped ("<a href=\"evo:view-certificate\">%s</a>", _("View certificate"));
 
-		markup = g_strconcat (error->message ? error->message : "",
-			error->message ? "\n" : "", link, NULL);
+		if (error->message && *error->message)
+			escaped = g_markup_escape_text (error->message, -1);
+
+		markup = g_strconcat (escaped ? escaped : "", escaped ? "\n" : "", link, NULL);
 
 		gtk_label_set_markup (GTK_LABEL (wd->running_label), markup);
 
+		g_free (escaped);
 		g_free (markup);
 		g_free (link);
 	} else if (error) {
@@ -545,10 +556,7 @@ collection_account_wizard_worker_finished_cb (EConfigLookup *config_lookup,
 			gtk_widget_set_sensitive (wd2->enabled_check, TRUE);
 		}
 
-		if (wizard->priv->running_result) {
-			e_simple_async_result_complete_idle_take (wizard->priv->running_result);
-			wizard->priv->running_result = NULL;
-		}
+		g_clear_pointer (&wizard->priv->running_result, e_simple_async_result_complete_idle_take);
 
 		g_object_notify (G_OBJECT (wizard), "can-run");
 
@@ -1865,6 +1873,7 @@ collection_account_wizard_constructed (GObject *object)
 			"valign", GTK_ALIGN_CENTER,
 			"visible", TRUE,
 			"ellipsize", PANGO_ELLIPSIZE_END,
+			"selectable", TRUE,
 			NULL);
 		wd->running_label = label;
 
@@ -2151,21 +2160,9 @@ collection_account_wizard_dispose (GObject *object)
 	g_clear_object (&wizard->priv->registry);
 	g_clear_object (&wizard->priv->config_lookup);
 	g_clear_object (&wizard->priv->finish_cancellable);
-
-	if (wizard->priv->workers) {
-		g_hash_table_destroy (wizard->priv->workers);
-		wizard->priv->workers = NULL;
-	}
-
-	if (wizard->priv->store_passwords) {
-		g_hash_table_destroy (wizard->priv->store_passwords);
-		wizard->priv->store_passwords = NULL;
-	}
-
-	if (wizard->priv->running_result) {
-		e_simple_async_result_complete_idle_take (wizard->priv->running_result);
-		wizard->priv->running_result = NULL;
-	}
+	g_clear_pointer (&wizard->priv->workers, g_hash_table_destroy);
+	g_clear_pointer (&wizard->priv->store_passwords, g_hash_table_destroy);
+	g_clear_pointer (&wizard->priv->running_result, e_simple_async_result_complete_idle_take);
 
 	for (ii = 0; ii <= E_CONFIG_LOOKUP_RESULT_LAST_KIND; ii++) {
 		g_clear_object (&wizard->priv->sources[ii]);
