@@ -1511,18 +1511,10 @@ mail_display_finalize (GObject *object)
 	EMailDisplayPrivate *priv;
 
 	priv = E_MAIL_DISPLAY_GET_PRIVATE (object);
-
-	if (priv->old_settings) {
-		g_hash_table_destroy (priv->old_settings);
-		priv->old_settings = NULL;
-	}
+	g_clear_pointer (&priv->old_settings, g_hash_table_destroy);
 
 	g_mutex_lock (&priv->remote_content_lock);
-	if (priv->skipped_remote_content_sites) {
-		g_hash_table_destroy (priv->skipped_remote_content_sites);
-		priv->skipped_remote_content_sites = NULL;
-	}
-
+	g_clear_pointer (&priv->skipped_remote_content_sites, g_hash_table_destroy);
 	g_hash_table_destroy (priv->attachment_flags);
 	g_clear_object (&priv->remote_content);
 	g_mutex_unlock (&priv->remote_content_lock);
@@ -1644,7 +1636,7 @@ mail_display_constructed (GObject *object)
 	e_web_view_register_content_request_for_scheme (web_view, "cid", content_request);
 	g_object_unref (content_request);
 
-	display->priv->attachment_view = g_object_ref_sink (e_attachment_bar_new (display->priv->attachment_store));
+	display->priv->attachment_view = E_ATTACHMENT_VIEW (g_object_ref_sink (e_attachment_bar_new (display->priv->attachment_store)));
 
 	ui_manager = e_attachment_view_get_ui_manager (display->priv->attachment_view);
 	if (ui_manager) {
@@ -1973,7 +1965,7 @@ mail_display_save_part_for_drop (CamelMimePart *mime_part,
 		part_filename = "mail-part";
 
 	tmp = g_strdup (part_filename);
-	e_filename_make_safe (tmp);
+	e_util_make_safe_filename (tmp);
 
 	filename = g_build_filename (path, tmp, NULL);
 	g_free (tmp);
